@@ -283,12 +283,16 @@ class JunOSDriver(NetworkDriver):
         self.device.cu.commit(ignore_warning=self.ignore_warning, **commit_args)
         if not self.lock_disable and not self.session_config_lock:
             self._unlock()
+        if self.config_private:
+            self.device.rpc.close_configuration()
 
     def discard_config(self):
         """Discard changes (rollback 0)."""
         self.device.cu.rollback(rb_id=0)
         if not self.lock_disable and not self.session_config_lock:
             self._unlock()
+        if self.config_private:
+            self.device.rpc.close_configuration()
 
     def rollback(self):
         """Rollback to previous commit."""
@@ -425,6 +429,9 @@ class JunOSDriver(NetworkDriver):
                 structured_object_data["class"] = current_class
 
             if structured_object_data["class"] == "Power":
+                # Make sure naming is consistent
+                sensor_object = sensor_object.replace("PEM", "Power Supply")
+
                 # Create a dict for the 'power' key
                 try:
                     environment_data["power"][sensor_object] = {}
